function  p = xautolag(y,crit,maxlag)

%=======================================================================================
% PURPOSE: 
% automatic lag selection (for AR models only)
% 
% INPUT: 
% y      = (nx1) data vector
% maxlag = maximum lag order
% crit   = information criteria: {AIC,BIC}
%
% OUTPUT: 
% p = detrmined lag order
%
% AUTHOR: 
% Marian Vavra (marian.vavra@gmail.com)
% 
% REFERENCES: 
% Ng and Perron (2005), Oxford Bulletin of Economics and Statistics
%=======================================================================================

T = length(y);
V   = zeros(maxlag,1);
AIC = zeros(maxlag,1);
BIC = zeros(maxlag,1);

N = T-maxlag;
for p=1:maxlag
        Ylag   = mlag(y,p,1);
        Y      = y(p+1:end);
        [Q,R]  = qr(Ylag,0);
        phi    = R\(Q'*Y);
        ehat   = y(p+1:end) - Ylag*phi;
        ehat   = ehat(maxlag+1:end);
        V(p)   = var(ehat,1);
        AIC(p) = log(V(p)) + 2*(p+1)/N;
        BIC(p) = log(V(p)) + (p+1)*log(N)/N;
end

switch crit
    
    case {'BIC','bic'}
        m = min(BIC);
        p = find(BIC==m);    
        
    case {'AIC','aic'}
        m = min(AIC);
        p = find(AIC==m);
        
end

